@@ -1,3 +1,5 @@
+import sys
+
 from junitparser import Error, Failure, JUnitXml
 from lxml import etree as ET
 
@@ -17,6 +19,7 @@ class JUnitChecker(WarningsChecker):
             content (str): The content to parse
         '''
         try:
+            is_valid_suite_name = False
             root_input = ET.fromstring(content.encode('utf-8'))
             testsuites_root = self.prepare_tree(root_input)
             suites = JUnitXml.fromelem(testsuites_root)
@@ -27,8 +30,13 @@ class JUnitChecker(WarningsChecker):
                     elif isinstance(testcase.result, (Failure, Error)):
                         self.print_when_verbose('{classname}.{testname}'.format(classname=testcase.classname,
                                                                                 testname=testcase.name))
+                    if testcase.classname.endswith(self.name):
+                        is_valid_suite_name = True
             suites.update_statistics()
             self.count += suites.failures + suites.errors
+            if not is_valid_suite_name and hasattr(self, 'check_suite_name') and self.check_suite_name:
+                print('ERROR: No suite with name {!r} found. Returning error code -1.'.format(self.name))
+                sys.exit(-1)
         except ET.ParseError as err:
             print(err)
 
